from setuptools import setup

setup(name='sokt',
      version='0.1.3',
      description='For invoking Socket flows',
      url='http://viasocket.com	',
      author='Viasocket',
      author_email='kadamb@walkover.in',
      license='MIT',
      packages=['sokt'],
      zip_safe=False)